@@ -1,8 +1,5 @@
 package Dist::Zilla::PluginBundle::AVAR;
-BEGIN {
-  $Dist::Zilla::PluginBundle::AVAR::AUTHORITY = 'cpan:AVAR';
-}
-BEGIN { $Dist::Zilla::PluginBundle::AVAR::VERSION = '0.33'; }
+BEGIN { $Dist::Zilla::PluginBundle::AVAR::VERSION = '0.34'; }
 use 5.10.0;
 use Moose;
 use Moose::Autobox;
@@ -41,7 +38,7 @@ sub bundle_config {
     my $cpan_id = try { $zilla->stash_named('%PAUSE')->username };
 
     my $authority   = $args->{authority} // ($cpan_id ? "cpan:$cpan_id" : 'cpan:AVAR');
-    my $no_Authority = $args->{no_Authority} // 0;
+    my $no_Authority = $args->{no_Authority} // 1;
     my $no_a_pre    = $args->{no_AutoPrereq} // 0;
     my $use_mm      = $args->{use_MakeMaker} // 1;
     my $use_ct      = $args->{use_CompileTests} // $args->{use_TestCompile} // 1;
@@ -244,8 +241,8 @@ This is the plugin bundle that AVAR uses. Use it as:
     use_MakeMaker = 0 ; If using e.g. MakeMaker::Awesome instead
     use_TestCompile = 0 ; I have my own compile tests here..
     ;; cpan:YOUR_CPAN_ID is the default authority, read from "dzil setup" entry for PAUSE
-    authority = cpan:AVAR
-    ; no_Authority = 1 ; If you don't want to use the authority module
+    ; authority = cpan:AVAR
+    no_Authority = 0 ; If want to use the authority module (previously the default)
     ;; if you want to install your dist after release (set $ENV{PERL_CPANM_OPTS} if you need --sudo or --mirror etc.)
     ;; default is OFF
     install_command = cpanm .
